==> haskell-cmdargs-0.10.22-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmdargs
version:              0.10.22
visibility:           public
id:                   cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
key:                  cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
license:              BSD-3-Clause
copyright:            Neil Mitchell 2009-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/cmdargs#readme
synopsis:             Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.

    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.

    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.

    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.

    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.

category:             Console
abi:                  93b585f9690c00f3e06d6734bdb7c3c6
exposed:              True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity

hidden-modules:
    Data.Generics.Any Data.Generics.Any.Prelude
    System.Console.CmdArgs.Explicit.Complete
    System.Console.CmdArgs.Explicit.ExpandArgsAt
    System.Console.CmdArgs.Explicit.Help
    System.Console.CmdArgs.Explicit.Process
    System.Console.CmdArgs.Explicit.SplitJoin
    System.Console.CmdArgs.Explicit.Type
    System.Console.CmdArgs.Implicit.Ann
    System.Console.CmdArgs.Implicit.Global
    System.Console.CmdArgs.Implicit.Local
    System.Console.CmdArgs.Implicit.Reader
    System.Console.CmdArgs.Implicit.Reform
    System.Console.CmdArgs.Implicit.Type
    System.Console.CmdArgs.Implicit.UI

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cmdargs-0.10.22
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cmdargs-0.10.22
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cmdargs-0.10.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmdargs
hs-libraries:         HScmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
depends:
    base-4.17.2.1 filepath-1.4.2.2 process-1.6.18.0
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html:         /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmdargs-0.10.22-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmdargs
version:              0.10.22
visibility:           public
id:                   cmdargs-0.10.22-1ARObHkVbOT1HJZIaJM1AG
key:                  cmdargs-0.10.22-1ARObHkVbOT1HJZIaJM1AG
license:              BSD-3-Clause
copyright:            Neil Mitchell 2009-2023
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/cmdargs#readme
synopsis:             Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.

    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.

    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.

    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.

    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.

category:             Console
abi:                  9b4219e3b43bc9bd5f7435d09802df6f
exposed:              True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity

hidden-modules:
    Data.Generics.Any Data.Generics.Any.Prelude
    System.Console.CmdArgs.Explicit.Complete
    System.Console.CmdArgs.Explicit.ExpandArgsAt
    System.Console.CmdArgs.Explicit.Help
    System.Console.CmdArgs.Explicit.Process
    System.Console.CmdArgs.Explicit.SplitJoin
    System.Console.CmdArgs.Explicit.Type
    System.Console.CmdArgs.Implicit.Ann
    System.Console.CmdArgs.Implicit.Global
    System.Console.CmdArgs.Implicit.Local
    System.Console.CmdArgs.Implicit.Reader
    System.Console.CmdArgs.Implicit.Reform
    System.Console.CmdArgs.Implicit.Type
    System.Console.CmdArgs.Implicit.UI

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/cmdargs-0.10.22
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/cmdargs-0.10.22
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/cmdargs-0.10.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmdargs
hs-libraries:         HScmdargs-0.10.22-1ARObHkVbOT1HJZIaJM1AG
depends:
    base-4.18.3.0 filepath-1.4.301.0 process-1.6.19.0
    template-haskell-2.20.0.0 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html:         /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
